@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect Musical Modal Functions
 
-our $VERSION = '0.0306';
+our $VERSION = '0.0307';
 
 use Moo;
 use strictures 2;
@@ -244,7 +244,7 @@ Music::ModalFunction - Inspect Musical Modal Functions
 
 =head1 VERSION
 
-version 0.0306
+version 0.0307
 
 =head1 SYNOPSIS
 
@@ -286,6 +286,10 @@ To bind a value to a fact or rule argument, declare it in the object
 constructor. Unbound arguments will return all the possible values
 that make the query true.
 
+The essential question is, "Can a chord in one key function in a
+second?" Any B<any> parts of this open-ended question may be unbound,
+thereby resulting in all possible truths.
+
 =head1 ATTRIBUTES
 
 =head2 chord_note
